@@ -30,6 +30,7 @@
 
 #include <QMessageBox>
 #include <QProcess>
+#include <QSettings>
 
 namespace Ui {
 class MainWindow;
@@ -49,7 +50,7 @@ protected:
     QProcess *proc;
 
 public:
-    explicit MainWindow(QWidget *parent = 0, QStringList args = QStringList());
+    explicit MainWindow(QWidget *parent = nullptr, QStringList args = QStringList());
     ~MainWindow();
 
     Result runCmd(QString cmd);
@@ -57,35 +58,34 @@ public:
 
     QString version;
     QString output;
+    bool isfluxbox = false;
 
     void setup();
 
 private slots:
-    void on_buttonAbout_clicked();
-    void on_checkBox_clicked(bool checked);
-    void on_buttonTools_clicked();
-    void on_buttonManual_clicked();
-    void on_buttonForum_clicked();
-    void on_buttonWiki_clicked();
-    void on_buttonVideo_clicked();
-    void on_buttonContribute_clicked();
-    void on_buttonPanelOrient_clicked();
-    void on_buttonPackageInstall_clicked();
-    void on_buttonCodecs_clicked();
-    void on_buttonFAQ_clicked();
-    void on_buttonSetup_clicked();
-
-    void on_buttonTOS_clicked();
-
     void on_ButtonQSI_clicked();
-    void shortsysteminfo();
-
+    void on_buttonAbout_clicked();
+    void on_buttonCodecs_clicked();
+    void on_buttonContribute_clicked();
+    void on_buttonFAQ_clicked();
+    void on_buttonForum_clicked();
+    void on_buttonManual_clicked();
+    void on_buttonPackageInstall_clicked();
+    void on_buttonPanelOrient_clicked();
+    void on_buttonSetup_clicked();
+    void on_buttonTOS_clicked();
+    void on_buttonTools_clicked();
+    void on_buttonVideo_clicked();
+    void on_buttonWiki_clicked();
+    void on_checkBox_clicked(bool checked);
     void on_tabWidget_currentChanged(int index);
     void resizeEvent(QResizeEvent*);
     void settabstyle();
+    void shortsysteminfo();
 
 private:
     Ui::MainWindow *ui;
+    QSettings user_settings;
 };
 
 
